ExIbge.Api (ex_ibge v0.4.0)

Copy Markdown View Source

Summary

Functions

Bangify a result.

Create a new client for a specific version of the API.

Types

t()

@type t() :: Req.Request.t()

Functions

bangify(arg1)

@spec bangify({:ok, any()} | {:error, any()} | :ok) :: any()

Bangify a result.

new!(version)

@spec new!(atom()) :: t()

Create a new client for a specific version of the API.