Struct representing a geographic name entry from the BNGB name list.
Summary
Types
@type t() :: %ExIbge.Bngb.GeoName{term: String.t() | nil}
Struct representing a geographic name entry from the BNGB name list.
@type t() :: %ExIbge.Bngb.GeoName{term: String.t() | nil}